'Scriptname: update.vbs
'Author: Muhr
'Date: 16.11.2005
'Last mod: 25.6.07
'Comment: 
' update a selection of critical EXE and DLL files which cannot be replaced while
' ATLAS.ti is still running as a separate process launched at the end of a service pack installation
' before closing the ATLAS.ti session
' collects all installed files with extension dl_ and ex_ and replaces their older counterparts
' if files to be installed ar enot newer they are removed
' logs all activities in the updates.log file which is also used by the service pack manager
'25.6.: determine app path by locating the scripts folder - also works when app path cannot be determined from the registry 

Option Explicit 'use only declared variables

Dim logFile, didUpdateFiles, folder 
Const doDebug = false
Const doUpdate = true
Const readRegistryToDetermineAppPath = false
Dim doLog

doLog = true

MsgBox "Attention: Your firewall might report this script as dangerous." & vbcrlf & "However, in order to complete the ATLAS.ti update in a consistent manner " & vbcrlf & "it is mandatory to permit execution of the script."& vbcrlf  & vbcrlf & "Press OK to continue.",vbOkOnly+vbExclamation+vbSystemModal,"Updating ATLAS.ti 5"

didUpdateFiles = false

If doLog Then InitLog

'Set folder = GetMyFolder
Set folder = GetATLAStiSharedSystemFolder

If doLog Then Log "Updating files in folder: " & folder.path

UpdateFiles CollectInstallFilesInFolder (folder), folder 

If didUpdateFiles Then 
  If doLog Then Log "Restarting ATLAS.ti ..."
  RestartATLASti 
Else
  If doLog Then Log "No critical files found to replace"
'  MsgBox "No critical files were replaced",0,"ATLAS.ti Restart not Neccessary"
  RestartATLASti 'because this script could also be started by a faked restart atlinit file
End If

If doLog Then CloseLog


'------------------ Procs & Functions -----------------------
Function CollectInstallFilesInFolder(aFolder)
 Dim selectedFiles()
 Dim ext, index, fso, newExt, file
 Set fso = WScript.CreateObject("Scripting.FileSystemObject")   
 index = 0.
 If doLog Then Log "Collecting update candidates."
 For each file in aFolder.Files
   ext = LCase(fso.GetExtensionName (file.Path))
'   If  ext = "dl_"  Or ext = "ex_" Or ext = "tx_" Then
   If  ext = "dl_"  Or ext = "ex_" Then
     If doDebug Then MsgBox "Type: " & ext,0, "Debug"
     ReDim Preserve selectedFiles(index)
     Select Case ext
       Case "dl_" newExt = Mid(ext, 1, len(ext)-1) & "l"
       Case "ex_" newExt = Mid(ext, 1, len(ext)-1) & "e"
       Case "tx_" newExt = Mid(ext, 1, len(ext)-1) & "t"
     End Select
     selectedFiles (index) = fso.GetBaseName(file.Name) & "." & newExt
     index = index + 1
   End If
 Next
 If index > 0 Then   WScript.Sleep 1000 'we need to be sure that ATLAS.ti has terminated in the meantime in order to replace critical files
 If doDebug Then MsgBox "Found " & Index & " *.xx_ Files",0, "File to be updated"  End If
 If doLog Then Log "Found " & index & " update candidates."  End If
 Set fso = nothing
 CollectInstallFilesInFolder = selectedFiles
End Function

Sub UpdateFiles(fileNames,folder)
  Dim fileName 
  For each fileName in fileNames
     UpdateFileNamed fileName, folder
  Next
End Sub

Sub UpdateFileNamed(aFileName, aFolder)
  'check if a newer file named *.xx_ exists and copy this to the file to be upgraded
  Dim fso, backupPath, myFolder, oldDate, folderPath, oldPath, installFilePath, installFileName, oldFile, newFile
  Set fso = WScript.CreateObject("Scripting.FileSystemObject")
  folderPath = aFolder.Path 
  oldPath = fso.BuildPath (folderPath,aFileName)
  If doDebug Then MsgBox oldPath,0, "File to be updated"  'End If
  If doLog Then Log "Attempting to update file " & aFileName  'End If
  If fso.FileExists(oldPath) Then
    If doDebug Then MsgBox oldPath,0, "File exists!"  
    installFileName = GetUpdateFileNameFor(aFileName)
    installFilePath = folderPath & "\" & installFileName
    If doDebug Then MsgBox "File to be installed: " & installFilePath,0, "File to be installed"  

    If (fso.FileExists (installFilePath)) Then  'a file to be installed exists
       Set oldFile = fso.GetFile(oldPath)
       Set newFile = fso.GetFile(installFilePath)
       If IsNewerFile (newFile, oldFile) Then
          oldDate = oldFile.DateLastModified  
          If doDebug Then MsgBox "File " & oldFile.Name & " modified " & oldDate  & " will be updated with newer version (" & newFile.DateLastModified  & ")"  'End If
          If doUpdate Then 
            backupPath = fso.BuildPath(folderPath,"Backup of " & aFileName)
            If doDebug Then MsgBox "About to backup file " & aFileName & " to " & backupPath  'End If
            oldFile.Copy backupPath,true
            If doDebug Then MsgBox "About to copy file " & newFile.Path & " to: " & oldFile.Path  'End If
            newFile.Copy oldFile.Path,true
            
            didUpdateFiles = true
          End If 'doUpdate
          If doLog Then Log "File " & oldFile.Path & " dated " & oldDate & " was sucessfully updated with newer version (" & newFile.DateLastModified & ")"
   

          If Not (IsNewerFile (newFile, oldFile)) Then 'the install file must have been successfully copied
 

             If doUpdate Then
                newFile.Delete(true) 'true also deletes read-only files
             End If
          End If
       Else 'IsNewerFile (newFile, oldFile) NOT
          If doDebug Then MsgBox "File " & oldFile.Name & " is not newer (" & oldFile.DateLastModified  & ") than the install file (" & newFile.DateLastModified & ")"  'End If
          If doLog Then Log "File " & oldFile.Name & " dated " & oldFile.DateLastModified  & " not not replaced."  'End If

          'We dont need the new dl_ or ex_ if it is not newer
          If doUpdate Then
             newFile.Delete(true) 'true also deletes read-only files
          End If
       End If 'IsNewerFile (newFile, oldFile) or not
    End If '(fso.FileExists (installFilePath))
  End If 'fso.FileExists(oldPath)
  Set fso = nothing
End Sub
 
Function GetMyFolder
  Dim fso, myFolder, path
  Set fso = WScript.CreateObject("Scripting.FileSystemObject")   
  path = fso.GetParentFolderName (WScript.ScriptFullName)
'Important to use Set to return an object, not a string:
  Set GetMyFolder = fso.GetFolder(path)
End Function

Function IsNewerFile(newFile, oldFile)
  IsNewerFile = oldFile.DateLastModified < newFile.DateLastModified 
End Function


Function GetUpdateFileNameFor(aFileName)
  GetUpdateFileNameFor = Mid(aFileName,1,Len(aFileName) - 1) & "_"
End Function



'----------------- LOG stuff ------------------
Sub InitLog
  Const OPEN_FILE_FOR_APPENDING = 8
  Dim folder, fso, logFilePath   
  Set fso = WScript.CreateObject("Scripting.FileSystemObject")
  Set folder = GetATLAStiServicePackFolder
  logFilePath = fso.BuildPath(GetATLAStiServicePackFolder, "updates.log")
  If doDebug Then MsgBox "Logfile path: " & logFilePath End If
  Err.Clear
  WScript.Sleep 1000 'wait two seconds in case we are too fast
  Set logFile = fso.OpenTextFile(logFilePath, OPEN_FILE_FOR_APPENDING, true)
'  Set logFile = OpenLogFile (logFilePath)
   If doDebug Then 
           MsgBox "Opened Logfile "  
  End If
  If Err.Number <> 0  Then
     'lets try once more:
     Set logFile = fso.OpenTextFile(logFilePath, OPEN_FILE_FOR_APPENDING, true)
        If Err.Number <> 0 Then
            doLog = false
        End If
  End If
  If doDebug Then 
           MsgBox "DoLog: " & doLog 
  End If
  If doLog Then 
      If doDebug Then 
           MsgBox "Opened Logfile "
     End If
     logFile.WriteLine ""
     Log "ATLAS.ti Post Update Critical File replacement started. Script: " & WScript.ScriptFullName
     Log "Service Pack Folder: " & folder
  End If
  Set fso = nothing
End Sub

Function OpenLogFile (logFilePath)
'return a TextStream object or does this not work????
  Dim fso
  If doDebug Then 
           MsgBox "Open log before wait "
  End If
  Set fso = WScript.CreateObject("Scripting.FileSystemObject")
  WScript.Sleep 2000 'wait two seconds
  If doDebug Then 
           MsgBox "Open log after wait "
  End If
 On Error Resume Next  
  Err.Clear
  Set OpenLogFile  = fso.OpenTextFile(logFilePath, OPEN_FILE_FOR_APPENDING, true)
  Set fso = nothing
  If Err.Number <> 0  Then
    Set OpenLogFile  = nothing
  End If
  On Error goto 0
End Function

Sub Log (textLine)
  logFile.WriteLine (Now() & ": " & textLine)
End Sub

Sub CloseLog
  Log "ATLAS.ti Post Update finished."
  logFile.Close
End Sub

'----------------- Paths stuff ------------------

Function GetATLAStiExePath
 Dim objWSHShell 
 Const regKey = "HKLM\SOFTWARE\MicroSoft\Windows\CurrentVersion\App Paths\atlasti.exe\Path"
 Set objWSHShell = WScript.CreateObject("WScript.Shell")
 GetATLAStiExePath = objWSHShell.RegRead (regKey)
 Set objWSHShell = nothing
End Function

Function RegValueExists(sRegValue)
     ' Returns True or False based of the existence of a registry value.
     Dim objWSHShell, RegReadReturn
     Set objWSHShell = CreateObject("WScript.Shell")
     RegValueExists = True  ' init value
     On Error Resume Next
     RegReadReturn = objWSHShell.RegRead(sRegValue)
     If Err.Number <> 0 Then
       RegValueExists = False
     End if
     On Error Goto 0
End Function

Function RegKeyExists(ByVal sRegKey)
    ' Returns True or False based on the existence of a registry key.

    Dim sDescription, oShell
    Set oShell = CreateObject("WScript.Shell")

    RegKeyExists = True
    sRegKey = Trim (sRegKey)
    If Not Right(sRegKey, 1) = "\" Then
      sRegKey = sRegKey & "\"
    End If

    On Error Resume Next
    oShell.RegRead "HKEYNotAKey\"
    sDescription = Replace(Err.Description, "HKEYNotAKey\", "")

    Err.Clear
    oShell.RegRead sRegKey
    RegKeyExists = sDescription <> Replace(Err.Description, sRegKey, "")
    On Error Goto 0
End Function


Function GetATLAStiServicePackFolder
   Set GetATLAStiServicePackFolder = GetATLAStiSharedSystemFolder.ParentFolder
End Function

Function GetATLAStiSharedSystemFolder
 Dim exePath, fso
 If Not readRegistryToDetermineAppPath Then
    Set GetATLAStiSharedSystemFolder = GetMyFolder 
 Else
    exePath = GetATLAStiExePath
    Set fso = WScript.CreateObject("Scripting.FileSystemObject")   
    Set GetATLAStiSharedSystemFolder = fso.GetFolder(exePath)
 End If
End Function

Function GetATLAStiExeName
   GetATLAStiExeName = "atlasti.exe" 
End Function

Sub RestartATLASti
 Dim res,path, objShell, fso  
 Set fso = WScript.CreateObject("Scripting.FileSystemObject")
 path = fso.BuildPath (GetATLAStiSharedSystemFolder,GetATLAStiExeName)
 If doLog Then Log "Launch using path: " & path End If
 path = """" & path & """"
 Set fso = nothing
 Set objShell = CreateObject("Wscript.Shell")
' objShell.Popup "ATLAS.ti will automatically restart in a few seconds." ,10,"Restarting  ATLAS.ti after Update",vbOKOnly+vbInformation + vbSystemModal
' res = MsgBox("Click YES to restart ATLAS.ti now (recommended)"+vbCrLf + "Click NO to finalize the update later." ,vbYesNo+vbInformation + vbSystemModal,"Finalizing ATLAS.ti Update")

res = vbYes

 If res = vbYes Then 
   objShell.Run path
   WScript.Sleep 2000
  End If

 if doDebug Then 
     objShell.Popup "Closing script ...",5,"Finishing ATLAS.ti Update",vbOKOnly+vbInformation 
 End If
 Set objShell = nothing
End Sub
'No linefeeds should follow this line