<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/> 
<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>


<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
  <friendlyName>Author</friendlyName> <!-- To be displayed in ATLAS.ti -->
  <shortDescription>displays all quotations, codes, and memos by author</shortDescription>
  <comment>this stylesheet displays all quotations, codes, and memos entered by each author. the interface is experimental in that it seeks to maximize the idea of "flexibility" by making all elements freely positionable on the screen. -- 
this stylesheet courtesy of ringmayr IT consulting (www.hypertexxt.com/atlas).
   </comment>
  <category>Report</category>
  <complexity>medium</complexity> <!-- Computational complexity -->
  <iconPath>hypertexxt.ico</iconPath> <!-- To be displayed in ATLAS.ti -->
  <author name="Thomas Ringmayr" email="atlas@hypertexxt.com" url="www.hypertexxt.com/atlas"/>
  <creationDate>2003-06-30</creationDate>
  <sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
  <targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">
<html>
<head>
	<xsl:call-template name="htmlhead"/>
	<xsl:call-template name="script_expandsection"/>
	<xsl:call-template name="script_drag"/>

<style type="text/css">
	.divCall {cursor: hand; }
	.divSection {margin-left: 20px; }
	.divGroup {cursor: hand; }
	.divElements {margin-left: 20px;}	
	.drag {position: relative; border: gray dashed 1px; cursor: move; width: 300px; padding:10px; background-image: url('images/bgGrid.gif');}
	body {background-image: url('images/bgGrid.gif');  }
	.elementTitle {color: red; }
	pre {font-family: Arial; color: #333333;}
	hr {color: teal; }
	
</style>
</head>

<body>
<xsl:variable name="authorlist">
<xsl:for-each select="//*[@au]">
<xsl:sort select="@au"/>
	<xsl:copy-of select="."/>
</xsl:for-each>
</xsl:variable>

<div width="50%" style="position: relative; left: 20%; background-image: url('');" class="drag">
<xsl:for-each select="msxsl:node-set($authorlist)/*[@au]" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
<xsl:variable name="author" select="@au"/>
<xsl:if test="not(following-sibling::*/@au =@au)">
<xsl:variable name="sectionID"><xsl:value-of select="generate-id()"/></xsl:variable>

<div onclick="doSection({$sectionID})" class="divCall">
	<img src="{$imagedir}squareTeal.gif" alt="{$author}" />
	<xsl:value-of select="$author"/>
</div>	

<div id="{$sectionID}" style="display:none;" class="divSection">

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">q</xsl:with-param>
		<xsl:with-param name="label">Quotations</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">code</xsl:with-param>
		<xsl:with-param name="label">Codes</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">memo</xsl:with-param>
		<xsl:with-param name="label">Memos</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">primDocFamily</xsl:with-param>
		<xsl:with-param name="label">Primary Document Family</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>


</div>

<hr/>
</xsl:if>
</xsl:for-each>


</div>

</body>
</html>
</xsl:template>

<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->

<xsl:template name="findElements">
<xsl:param name="what"/>
<xsl:param name="label"/>
<xsl:param name="author"/>
<xsl:param name="sectionID"/>
<xsl:param name="positionX"/>
<xsl:param name="positionY"/>

<xsl:variable name="groupID"><xsl:value-of select="concat($what, $sectionID)"/></xsl:variable>
<xsl:choose>
	<xsl:when test="//*[name() = $what and @au=$author] ">
		<div onClick="doSection({$groupID})" class="divGroup">
		
			<img src="{$imagedir}squareRed.gif" alt="{$label}" />

			<xsl:value-of select="$label"/> 
			(<xsl:value-of select="count(//*[name()=$what and @au = $author])"/>)
		</div>
		
		<div id="{$groupID}" style="display:none;" class="divElements">
		<xsl:for-each select="//*[name() = $what and @au=$author] ">
		<xsl:sort select="name()"/>
		<xsl:variable name="elementID"><xsl:value-of select="generate-id()"/></xsl:variable>
			<br/>
			
			<div class="drag" id="{$elementID}">
			<!--<img src="{$imagedir}close2.gif" alt="close" onclick="noSection({$elementID})" /><br/>-->
			<xsl:call-template name="displayElement">
				<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
				<xsl:with-param name="label"><xsl:value-of select="$label"/></xsl:with-param>
				<xsl:with-param name="what"><xsl:value-of select="$what"/></xsl:with-param>
				<xsl:with-param name="elementID"><xsl:value-of select="$elementID"/></xsl:with-param>
			</xsl:call-template>

<!--
			<xsl:if test="child::comment">
				<br/><pre><xsl:value-of select="comment"/></pre>
			</xsl:if>
-->			
		</div>
		</xsl:for-each>
	</div>
	</xsl:when>
	<xsl:otherwise><!--(no <xsl:value-of select="$label"/> for author <xsl:value-of select="$author"/>)--></xsl:otherwise>
</xsl:choose>

</xsl:template>

<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->

<xsl:template name="displayElement">
<xsl:param name="what"/>
<xsl:param name="label"/>
<xsl:param name="author"/>
<xsl:param name="elementID"/>


<xsl:if test="ancestor::primDoc">
	<div class="elementTitle"><strong>Primary Doc</strong>: <xsl:value-of select="ancestor::primDoc/@name"/></div>
</xsl:if>


<table width="100%" cellspacing="2" cellpadding="0" border="0">
	<tr><td>
		<div class="" style="background-color: #EEEEEE; cursor: hand;" onClick="doSection(sub{$elementID})" >
		<img src="{$imagedir}miniSquare.gif" alt="{@name}" />
		<xsl:value-of select="@name"/></div>
	</td></tr>
</table>
	

<table width="100%" cellspacing="2" cellpadding="0" border="0" id="sub{$elementID}" style="display:none;">

<xsl:for-each select="@*[.!='' and name()!= 'name']">

<xsl:choose>
	<xsl:when test="name()='au'"></xsl:when>

	<xsl:when test="name()='cDate'">
		<tr><td  width="20%">
		<strong>created</strong></td><td><xsl:value-of select="substring(., 6,2)"/>-<xsl:value-of select="substring(., 9,2)"/>-<xsl:value-of select="substring(., 1,4)"/></td></tr></xsl:when>

	<xsl:when test="name()='mDate'">
			<tr><td >
		<strong>modified</strong></td><td><xsl:value-of select="substring(., 6,2)"/>-<xsl:value-of select="substring(., 9,2)"/>-<xsl:value-of select="substring(., 1,4)"/></td></tr></xsl:when>
	<xsl:otherwise><tr><td >
		<strong><xsl:value-of select="name()"/></strong></td><td><xsl:value-of select="."/></td></tr></xsl:otherwise>
</xsl:choose>
</xsl:for-each>
			<xsl:if test="child::comment">
				<tr>
				<td colspan="2"><br/>
					<pre><xsl:value-of select="comment"/></pre>
				</td>
				</tr>
			</xsl:if>
</table>
</xsl:template>


<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->


</xsl:stylesheet>

