<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/> 
<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>Code Network Synopsis</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>A list of codes, links and relation prototypes</shortDescription>
<comment>Creates a synopsis of codes, links and relations.</comment>
<category>Report</category>
<complexity>medium</complexity> <!-- Computational complexity -->
<iconPath>synopsis.ico</iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Muhr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-05-31</creationDate>
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">

<html>
<head>
<xsl:call-template name="htmlhead"/>
<xsl:call-template name="script_expandsection"/>
</head>

<body>
<xsl:call-template name="pagehead"/>

<h1 class="title">Code Network Synopsis</h1>
<hr/>

<div class="section">

<!-- nodes       -->
<h1>Nodes</h1>

<xsl:for-each select="//code">
<xsl:sort select="@name"/>
<span class="red"><xsl:value-of select="@name"/></span> [<xsl:value-of select="@au"/>]<xsl:if test="following-sibling::code"> - </xsl:if>
</xsl:for-each>
</div>




<div class="section">
<!-- relation prototypes -->
<h1>Relation Prototypes</h1>

<xsl:for-each select="//codeLinkProto">
<xsl:variable name="id"><xsl:value-of select="generate-id()"/></xsl:variable>
<span class="red"><xsl:value-of select="@id"/></span> [<xsl:value-of select="@descr"/>, <xsl:value-of select="@au"/>, <xsl:value-of select="@formalProp"/>]

	<xsl:if test="comment and comment!=''"> - 
	<span style="cursor:hand;" class="red">
	<xsl:attribute name="onClick">doSection(comment<xsl:value-of select="$id"/>)</xsl:attribute>
	<img src="{$imagedir}mark.gif" alt="more info" border="0"/>
	more info
	</span>

	<div style="display:none; border:1px solid; position:absolute; background-color: lightyellow; padding:5px; " >
	<xsl:attribute name="id">comment<xsl:value-of select="$id"/></xsl:attribute>

		<div class="commenttext">
			<xsl:choose>
				<xsl:when test="@type='text/html'">
						<xsl:for-each select="*">
							<xsl:copy-of select="." />
						</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
						<xsl:value-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
		</div>

	</div>
	</xsl:if>

<br/>
</xsl:for-each>
</div>




<div class="section">
<!-- codeLinks --> 
<h1>Code Links</h1>

<xsl:for-each select="storedHU/codes/code">
<xsl:variable name="codeid"><xsl:value-of select="@id"/></xsl:variable>
<xsl:variable name="codename"><xsl:value-of select="@name"/></xsl:variable>

	<xsl:for-each select="//codeLink[@source = $codeid]">
	<xsl:variable name="id">cl<xsl:value-of select="generate-id()"/></xsl:variable>
	<xsl:variable name="linkTarget"><xsl:value-of select="@target"/></xsl:variable>
	<xsl:variable name="linkRelation"><xsl:value-of select="@rel"/></xsl:variable>
	<span class="red;"><xsl:value-of select="$codename "/></span><xsl:text> </xsl:text>
	<xsl:value-of select="//codeLinkProto[@id=$linkRelation]/@descr"/>
	<xsl:text> </xsl:text>
	<span class="blue"><xsl:value-of select="//code[@id=$linkTarget]/@name "/></span>

	<xsl:if test="comment and comment!=''"> - 
	<span style="cursor:hand;" class="red">
	<xsl:attribute name="onClick">doSection(comment<xsl:value-of select="$id"/>)</xsl:attribute>
	<img src="{$imagedir}mark.gif" alt="more info" border="0"/>
	more info
	</span>

	<div style="display:none; border:1px solid; position:absolute; background-color: lightyellow; padding:5px; " >	<xsl:attribute name="id">comment<xsl:value-of select="$id"/></xsl:attribute>
		<pre class="commenttext">(<xsl:value-of select="comment"/>)</pre>
	</div>
	</xsl:if>
	<br/>
	</xsl:for-each>

</xsl:for-each>

</div>

</body>
</html>
</xsl:template>

</xsl:stylesheet>

