<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet 
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:msxsl="urn:schemas-microsoft-com:xslt">


<xsl:output method="xml"
   doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
   doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
   omit-xml-declaration="yes" indent="yes" />


<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>Print Codes in Full</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>A list of codes with all quotations, ready to print.</shortDescription>
<comment></comment>
<category>Report</category>
<complexity>medium</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2007-11-09</creationDate>
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>




<xsl:template match="/">

<xsl:variable name="uniquelist">

<xsl:for-each select="storedHU/links/objectSegmentLinks/codings/iLink">
<xsl:sort select="@obj" />

	<xsl:variable name="obj"><xsl:value-of select="@obj"/></xsl:variable>
	<xsl:if test="not(following-sibling::iLink/@obj=$obj) ">

		<xsl:element name="item">
				<xsl:attribute name="code"><xsl:value-of select="@obj"/></xsl:attribute>
			<xsl:attribute name="count"><xsl:value-of select="count(//iLink[@obj = $obj])"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="//code[@id = $obj]/@name"/></xsl:attribute>			
		
			<xsl:for-each select="ancestor::codings/iLink[@obj=$obj]">
				<xsl:variable name="qRef"><xsl:value-of select="@qRef"/></xsl:variable>

					<xsl:element name="quote">
						<xsl:attribute name="qRef"><xsl:value-of select="$qRef"/></xsl:attribute>


					<xsl:for-each select="//q[@id=$qRef]">
					<xsl:variable name="position">
						<xsl:number count="q" level="any" />
					</xsl:variable>
	
					<xsl:choose>
						<xsl:when test="content and content/@size &lt;1000">
							<xsl:element name="content">
								<xsl:attribute name="source"><xsl:value-of select="ancestor::primDoc/@name"/></xsl:attribute>
								<xsl:attribute name="quotenr"><xsl:value-of select="substring-after(@id, '_')"/></xsl:attribute>
								<xsl:attribute name="position"><xsl:value-of select="$position"/></xsl:attribute>

								
									<xsl:copy-of select="content"/>
							</xsl:element>
						</xsl:when>
						
						<xsl:otherwise>
							<xsl:element name="content">
								<xsl:attribute name="source"><xsl:value-of select="ancestor::primDoc/@name"/></xsl:attribute>
								<xsl:attribute name="quotenr"><xsl:value-of select="substring-after(@id, '_')"/></xsl:attribute>
								<xsl:attribute name="position"><xsl:value-of select="$position"/></xsl:attribute>


									<xsl:value-of select="@name"/>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>

			


		</xsl:for-each>
					</xsl:element>
			</xsl:for-each>
	</xsl:element>

	</xsl:if>	
</xsl:for-each>
</xsl:variable>




<!-- /////////////////////////////////////////////////////////////////////////-->

<html xmlns="http://www.w3.org/1999/xhtml">

<head>
	<xsl:call-template name="htmlhead"/>
    <link rel="stylesheet" type="text/css" href="styles/codeprintlist.css" media="screen,projection"/>
    <link rel="stylesheet" type="text/css" href="styles/codeprintlist.css" media="print"/>

</head>

<body id="printcodelist">
<xsl:call-template name="pagehead"/>

<h1 class="title">Printable Codes in Full</h1>
<p>HU: <xsl:value-of select="storedHU/hermUnit/@name"/></p>


<xsl:for-each select="msxsl:node-set($uniquelist)//item[@name!='']">
<xsl:sort select="@name" />

<xsl:variable name="id" select="generate-id()"/>
<xsl:variable name="obj" select="@obj"/>
<xsl:variable name="name" select="@name"/>
<xsl:variable name="counter" select="position() + 1"/>


<div class="contentsection">

<h2>
	<span class="hvar">Code: </span><xsl:value-of select="@name"/>
</h2>


<xsl:for-each select="quote/content">

	<div class="contentdiv">

		<h3>
			<span class="hvar">Quotation Nr: </span>
			<xsl:value-of select="@quotenr"/>
			<xsl:text> - </xsl:text>
			<span class="hvar">Source: </span>
			<xsl:value-of select="@source"/>
		</h3>

			<div class="contentdivInner">
				<xsl:copy-of select="content/*"/>
			</div>

	</div>

</xsl:for-each>

</div>

</xsl:for-each>


</body>
</html>
</xsl:template>

</xsl:stylesheet>

