<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output method="xml"
   doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
   doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
   omit-xml-declaration="yes" indent="yes" />

<xsl:variable name= "description" select="document('')//atlasDescription" />

<xsl:include href="+a6_shared.xsl"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>CSS Switcher</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>Switch dynamically between CSS stylesheets and view your data in vastly different presentational styles. </shortDescription>
<howTo>
Use the inline menu to apply different CSS stylesheets to the same basic HTML output. 
</howTo> 
<comment>
Live and instantenous switching between COMPLETELY different looks and layouts of your output. Style your data any way you like. Create effective and stylish presentations for on- and offline use.  
</comment>
<category>Report</category>
<complexity>medium</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-06-30</creationDate>
<modificationDate>2007-11-01</modificationDate>
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>




<xsl:template match="/">

<html xmlns="http://www.w3.org/1999/xhtml">

<head>
	<xsl:call-template name="htmlhead"/>

	<xsl:call-template name="script_expandsection"/>
	<xsl:call-template name="script_switchCSS"/>

	
    <link rel="stylesheet" type="text/css" href="styles/printMain.css" media="print"/>

    <style type="text/css">
		#atlasfooter {
			padding: 10px; 
			margin-top: 40px; 
			line-height: 25px; 
		}
		
		#atlasfooter p {
			text-align: center; 
			font-size: 8pt; 
		}    
    </style>

</head>


<body>
<div id="container">

<div id="header">

	<h1><xsl:value-of select="//hermUnit/@name"/></h1>
	
	<div id="menu">
	<ul>
		<li><a href="#" onmousedown="switchStyles('{$stylesdir}switch_darktheme.css')">Dark</a></li>
		<li><a href="#" onmousedown="switchStyles('{$stylesdir}switch_deepred.css')">Red</a></li>
		<li><a href="#" onmousedown="switchStyles('{$stylesdir}switch_simplyred.css')">Scroll</a></li>
		<li><a href="#" onmousedown="switchStyles('{$stylesdir}switch_redking.css')">Manga</a></li>
		<li><a href="#" onmousedown="switchStyles('{$stylesdir}_shared.css')">Plain</a></li>
	</ul>
</div>
	
	<div id="visual"  class="visual"></div>

</div>




<div id="content">

	<h2 id="huinfo">HU Info</h2>

	<div id="infotext">
		<xsl:value-of select="storedHU/hermUnit/comment"/>
	</div>
	


	<h2 id="hucontent">HU Content</h2>

	<div id="text">

	<p>This project contains <xsl:value-of select="count(storedHU/codes/code)"/> codes: </p>

	<ul>

<xsl:for-each select="storedHU/codes/code">
<xsl:sort select="@name"/>

<xsl:variable name="objid"><xsl:value-of select="@id"/></xsl:variable>
<xsl:variable name="id"><xsl:value-of select="generate-id()"/></xsl:variable>

<xsl:choose>
	<xsl:when test="//objectSegmentLinks/codings/iLink[@obj=$objid]">
		<li>
		<xsl:value-of select="@name"/>
		(<xsl:value-of select="count(//objectSegmentLinks/codings/iLink[@obj=$objid])"/>)
		</li>

	<!--
		<div style="display:none">
		<xsl:attribute name="id">list<xsl:value-of select="$id"/></xsl:attribute>
			
		<ul class="listInner">
		
		<xsl:for-each select="ancestor::storedHU/links/objectSegmentLinks/codings/iLink[@obj=$objid]">
		<xsl:sort select="@name"/>
		<xsl:variable name="target"><xsl:value-of select="@qRef"/></xsl:variable>
		<li class="itemInner"><xsl:value-of select="//q[@id=$target]/@name"/></li>
		</xsl:for-each>

		</ul>
		</div>
-->		
	</xsl:when>

	<xsl:otherwise>
		<li><xsl:value-of select="@name"/></li>
	</xsl:otherwise>
	
</xsl:choose>


</xsl:for-each>

</ul>

</div>
</div>		



<div id="footer">
	<xsl:call-template name="simplepagefooter" />
</div>

<xsl:call-template name="atlasfooter">
	<xsl:with-param name="withimage">no</xsl:with-param>
</xsl:call-template>

<div id="left"></div>
<div id="right"></div>


</div>


</body>
</html>
</xsl:template>

</xsl:stylesheet>

