<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:msxsl="urn:schemas-microsoft-com:xslt"
	version="1.0"> 

<xsl:output method="xml" indent="yes"/> 
<xsl:variable name= "description" select="document('')//atlasDescription" />

<xsl:include href="+a6_shared.xsl"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->

<friendlyName>HU Tag Cloud</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>A simple tag cloud viewer browser for HU entities</shortDescription>
<howTo>Hold down left mouse button on tag to preview available quotes. Double-click to view in detail. -- Close each code window before opening a new one to avoid potential clutter and overlap. Reload the page (Ctrl-R) if code window becomes clutttered. </howTo>
<comment>
A tag cloud is a visual depiction of content tags used in your HU. More frequently used tags are depicted in a larger font or otherwise emphasized, while the displayed order is generally alphabetical. Thus both finding a tag by alphabet and by frequency is possible. 	
</comment>
<category>Viewer</category>
<complexity>medium</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2007-10-15</creationDate>
<modificationDate>2007-10-15</modificationDate>  
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<!-- /////////////////////////////////////////////////////////////////////////////////// -->

<xsl:template match="/">


<xsl:variable name="uniquelist">

<xsl:for-each select="storedHU/links/objectSegmentLinks/codings/iLink">
<xsl:sort select="@obj" />

	<xsl:variable name="obj"><xsl:value-of select="@obj"/></xsl:variable>
	<xsl:if test="not(following-sibling::iLink/@obj=$obj) ">

		<xsl:element name="item">

			<xsl:attribute name="code"><xsl:value-of select="@obj"/></xsl:attribute>
			<xsl:attribute name="count"><xsl:value-of select="count(//iLink[@obj = $obj])"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="//code[@id = $obj]/@name"/></xsl:attribute>			
		

			<xsl:for-each select="ancestor::codings/iLink[@obj=$obj]">
				<xsl:variable name="qRef"><xsl:value-of select="@qRef"/></xsl:variable>

					<xsl:element name="quote">
						<xsl:attribute name="qRef"><xsl:value-of select="$qRef"/></xsl:attribute>

		<xsl:for-each select="//q[@id=$qRef]">
		
						<xsl:if test="content and content/@size &lt;1000">
							<xsl:element name="content">
								<xsl:attribute name="source"><xsl:value-of select="ancestor::primDoc/@name"/></xsl:attribute>
							
								<xsl:copy-of select="content/*"/>
							</xsl:element>
						</xsl:if>

		</xsl:for-each>
					</xsl:element>
			</xsl:for-each>
	</xsl:element>

	</xsl:if>	
</xsl:for-each>
</xsl:variable>



<xsl:variable name="min">
<xsl:for-each select="msxsl:node-set($uniquelist)//item">
<xsl:sort select="@count"  order="ascending" data-type="number"/>

<xsl:if test="position()=1">
<xsl:value-of select="@count" />
</xsl:if>
</xsl:for-each>
</xsl:variable>


<xsl:variable name="max">
<xsl:for-each select="msxsl:node-set($uniquelist)//item">
<xsl:sort select="@count"  order="ascending" data-type="number"/>

<xsl:if test="position()=last()">
<xsl:value-of select="@count" />
</xsl:if>
</xsl:for-each>
</xsl:variable>

<xsl:variable name="range" select="$max - $min"/>

<xsl:variable name="step" select="$range div 58 "/>


<!-- ////////////////////////////////////////////// -->


<html xmlns="http://www.w3.org/1999/xhtml">

<head>
	<xsl:call-template name="htmlhead"/>
	<xsl:call-template name="script_expandsection"/>
	<xsl:call-template name="script_tabcontent"/>
	<xsl:call-template name="script_stickynote"/>

    <link rel="stylesheet" type="text/css" href="styles/tagcloud.css" media="screen,projection"/>
    <link rel="stylesheet" type="text/css" href="styles/printMain.css" media="print"/>
    
</head>

<body>

<xsl:call-template name="pagehead"/>

<h1 class="title">Tag Cloud</h1>

<h2 class="title"><span class="hvar">HU:</span> <xsl:value-of select="//hermUnit/@name"/></h2>



<div class="tags">

<xsl:for-each select="msxsl:node-set($uniquelist)//item">
<xsl:sort select="@name" />

<xsl:variable name="id" select="generate-id()"/>

<xsl:variable name="obj" select="@obj"/>

<xsl:variable name="name" select="@name"/>

<xsl:variable name="counter" select="position() + 1"/>


<xsl:variable name="size">
		<xsl:number value=" (@count  div  ($max div 58) ) + 6" format="99"/>
</xsl:variable>



<a class="s{$size}" href="#{$id}" onclick="doSection({$id})">
			<xsl:value-of select="@name" />
			<!--
			 (<xsl:value-of select="@count"/>)
		     -->
</a>

<xsl:text > </xsl:text>



<div id="{$id}" style="display:none; z-index: {$counter}" class="contentsection">

		<xsl:call-template name="closeButton">
			<xsl:with-param name="id">
				<xsl:value-of select="$id"/>
			</xsl:with-param>
		</xsl:call-template>
		
	
		<h2>
			<span class="hvar">Code: </span><xsl:value-of select="$name"/>
		</h2>
	
	<xsl:for-each select="quote">

		<div class="contentdiv">
			<h3><span class="hvar">Source: </span><xsl:value-of select="content/@source"/></h3>
			<xsl:copy-of select="content"/>
		</div>

 	</xsl:for-each>

</div>


</xsl:for-each>

</div>

<!--
<xsl:call-template name="atlasfooter" />
-->

</body>
</html>
</xsl:template>


<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! -->


<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! -->
<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! -->



</xsl:stylesheet>
