<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:output method="xml"
   doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
   doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
   omit-xml-declaration="yes" indent="yes" />


<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>Author</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>displays all quotations, codes, and memos by author</shortDescription>
<comment>this stylesheet displays all quotations, codes, and memos entered by each author. the interface is experimental in that it seeks to maximize the idea of "flexibility" by making all elements freely positionable on the screen. -- 
this stylesheet courtesy of ringmayr IT consulting (www.hypertexxt.com/atlas).
</comment>
<category>Report</category>
<complexity>medium</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-06-30</creationDate>
<modificationDate>2007-11-01</modificationDate>
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">

<xsl:variable name="authorlist">
<xsl:for-each select="//*[@au]">
<xsl:sort select="@au"/>
	<xsl:copy-of select="."/>
</xsl:for-each>
</xsl:variable>





<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<xsl:call-template name="htmlhead"/>
	<xsl:call-template name="script_expandsection"/>
</head>

<body>

<xsl:call-template name="pagehead"/>

<h1 class="title">Elements by Authors</h1>

<div id="container">

<xsl:for-each select="msxsl:node-set($authorlist)/*[@au]" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
<xsl:variable name="author" select="@au"/>
<xsl:if test="not(following-sibling::*/@au =@au)">
<xsl:variable name="sectionID"><xsl:value-of select="generate-id()"/></xsl:variable>

<div onclick="doSection({$sectionID})" class="divCall">
	<img src="{$imagedir}mark.gif" alt="{$author}" />
	<xsl:value-of select="$author"/>
</div>	

<div id="{$sectionID}" style="display:none;" class="divSection">

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">q</xsl:with-param>
		<xsl:with-param name="label">Quotations</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">code</xsl:with-param>
		<xsl:with-param name="label">Codes</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">memo</xsl:with-param>
		<xsl:with-param name="label">Memos</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="findElements">
		<xsl:with-param name="what">primDocFamily</xsl:with-param>
		<xsl:with-param name="label">Primary Document Family</xsl:with-param>
		<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
		<xsl:with-param name="sectionID"><xsl:value-of select="$sectionID"/></xsl:with-param>
	</xsl:call-template>


</div>

<hr/>
</xsl:if>
</xsl:for-each>

</div>


</body>
</html>
</xsl:template>

<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->

<xsl:template name="findElements">
<xsl:param name="what"/>
<xsl:param name="label"/>
<xsl:param name="author"/>
<xsl:param name="sectionID"/>
<xsl:param name="positionX"/>
<xsl:param name="positionY"/>

<xsl:variable name="groupID"><xsl:value-of select="concat($what, $sectionID)"/></xsl:variable>
<xsl:choose>
	<xsl:when test="//*[name() = $what and @au=$author] ">
		<div onClick="doSection({$groupID})" class="divGroup">
		
			<img src="{$imagedir}mark.gif" alt="{$label}" />

			<xsl:value-of select="$label"/> 
			(<xsl:value-of select="count(//*[name()=$what and @au = $author])"/>)
		</div>
		
		<div id="{$groupID}" style="display:none;" class="divElements">
		<xsl:for-each select="//*[name() = $what and @au=$author] ">
		<xsl:sort select="name()"/>
		<xsl:variable name="elementID"><xsl:value-of select="generate-id()"/></xsl:variable>

			
			<div class="drag" id="{$elementID}">
			<!--<img src="{$imagedir}close2.gif" alt="close" onclick="noSection({$elementID})" /><br/>-->
			<xsl:call-template name="displayElement">
				<xsl:with-param name="author"><xsl:value-of select="$author"/></xsl:with-param>
				<xsl:with-param name="label"><xsl:value-of select="$label"/></xsl:with-param>
				<xsl:with-param name="what"><xsl:value-of select="$what"/></xsl:with-param>
				<xsl:with-param name="elementID"><xsl:value-of select="$elementID"/></xsl:with-param>
			</xsl:call-template>

<!--
			<xsl:if test="child::comment">
				<br/><pre><xsl:value-of select="comment"/></pre>
			</xsl:if>
-->			
		</div>
		</xsl:for-each>
	</div>
	</xsl:when>
	<xsl:otherwise><!--(no <xsl:value-of select="$label"/> for author <xsl:value-of select="$author"/>)--></xsl:otherwise>
</xsl:choose>

</xsl:template>

<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->

<xsl:template name="displayElement">
<xsl:param name="what"/>
<xsl:param name="label"/>
<xsl:param name="author"/>
<xsl:param name="elementID"/>





<table width="100%" cellspacing="2" cellpadding="0" border="0">
	<tr><td>
		<div class="result" onClick="doSection(sub{$elementID})" >
		<img src="{$imagedir}mark.gif" alt="{@name}" />
			<xsl:value-of select="@name"/>
		</div>


<xsl:if test="ancestor::primDoc">
	<div class="elementTitle">
		<xsl:text>[</xsl:text>
		<strong>Primary Doc</strong>: <xsl:value-of select="ancestor::primDoc/@name"/>
		<xsl:text>]</xsl:text>
		
	</div>
</xsl:if>

	</td></tr>
</table>
	

<table width="100%" cellspacing="2" cellpadding="0" border="0" id="sub{$elementID}" style="display:none;">

<xsl:for-each select="@*[.!='' and name()!= 'name']">

<xsl:choose>
	<xsl:when test="name()='au'"></xsl:when>

	<xsl:when test="name()='cDate'">
		<tr><td  width="20%">
		<strong>created</strong></td><td><xsl:value-of select="substring(., 6,2)"/>-<xsl:value-of select="substring(., 9,2)"/>-<xsl:value-of select="substring(., 1,4)"/></td></tr></xsl:when>

	<xsl:when test="name()='mDate'">
			<tr><td >
		<strong>modified</strong></td><td><xsl:value-of select="substring(., 6,2)"/>-<xsl:value-of select="substring(., 9,2)"/>-<xsl:value-of select="substring(., 1,4)"/></td></tr></xsl:when>
	<xsl:otherwise><tr><td >
		<strong><xsl:value-of select="name()"/></strong></td><td><xsl:value-of select="."/></td></tr></xsl:otherwise>
</xsl:choose>
</xsl:for-each>
			<xsl:if test="child::comment">
				<tr>
				<td colspan="2">
				
					<div class="commenttext">
						<xsl:choose>
							<xsl:when test="comment/@type='text/html'">
								<xsl:for-each select="comment/*">
										<xsl:copy-of select="." />
								</xsl:for-each>
								</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="comment"/>
							</xsl:otherwise>
						</xsl:choose>
					</div>

				</td>
				</tr>
			</xsl:if>
</table>

<br/>
</xsl:template>


<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->


</xsl:stylesheet>

