<?xml version="1.0" encoding="utf-8"?>


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:output method="xml"
   doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
   doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
   omit-xml-declaration="yes" indent="yes" />

<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>Quotations List (by Primary Document)</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>Lists all quotations as a simple numbered list</shortDescription>
<comment></comment>
<category>Viewer</category>
<complexity>simple</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-06-30</creationDate>
<modificationDate>2007-11-01</modificationDate>
<sourceType type="HU" version="5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">

<html xmlns="http://www.w3.org/1999/xhtml">

<head>
	<xsl:call-template name="htmlhead"/>
	<xsl:call-template name="script_expandsection"/>
</head>

<body>

<xsl:call-template name="pagehead"/>

<h1 class="title">Quotations per PD Viewer</h1>

<div id="container">

<div>
No. of Primary Documents: <xsl:value-of select="count(//primDoc)"/><br/>
Average Number of Quotes: <xsl:value-of select="round( (count(//primDoc/*/q )) div (count(//primDoc)) )"/>
</div>


<xsl:for-each select="//primDoc">
<xsl:variable name="docid"><xsl:value-of select="generate-id()"/></xsl:variable>
<p>
<xsl:value-of select="position()"/>. 
<xsl:value-of select="@name" /> - Created <xsl:call-template name="properCDate"/> by <xsl:value-of select="@au" />
<br/>

<xsl:if test="comment">
		<span style="color:teal; cursor:hand;">
		<xsl:attribute name="onClick">doSection(<xsl:value-of select="$docid"/>)</xsl:attribute>
		<img src="{$imagedir}mark.gif" border="0" alt="more info"/>
		more info
		</span>
	
	<div style="display:none; border:1px solid; position:absolute; background-color: lightyellow; padding:1px; " >
	<xsl:attribute name="id"><xsl:value-of select="$docid"/></xsl:attribute>

	<span style="color:teal; cursor:hand;">
	<xsl:attribute name="onClick">noSection(<xsl:value-of select="$docid"/>)</xsl:attribute>
	<img src="{$imagedir}close.gif" alt="close" border="0"/>
	</span>

		<div class="commenttext">
				<xsl:choose>
					<xsl:when test="comment/@type='text/html'">
						<xsl:for-each select="comment/*">
							<xsl:copy-of select="." />
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="comment"/>
					</xsl:otherwise>
				</xsl:choose>
		</div>

	</div>
</xsl:if>

</p>

<ol>
	<xsl:for-each select="quotations/q">
	<xsl:sort select="@name"/>
	<xsl:variable name="quotid"><xsl:value-of select="generate-id()"/></xsl:variable>
	<li>
	<xsl:value-of select="@name"/>  (<xsl:call-template name="properCDate"/>, by <xsl:value-of select="@au"/>)
	
	<xsl:if test="comment">
		<span style="color:teal; cursor:hand;">
		<xsl:attribute name="onClick">doSection(<xsl:value-of select="$quotid"/>)</xsl:attribute>
		<img src="{$imagedir}mark.gif" border="0" alt="show more"/>
		- show more
		</span>
	
	<div style="display:none; border:1px solid; position:relative; background-color: lightyellow; padding:1px; " >
	<xsl:attribute name="id"><xsl:value-of select="$quotid"/></xsl:attribute>

	<span style="cursor:hand;">
	<xsl:attribute name="onClick">noSection(<xsl:value-of select="$quotid"/>)</xsl:attribute>
	<img src="{$imagedir}close.gif" alt="close" border="0"/>
	</span>
	
		<div class="commenttext">
				<xsl:choose>
					<xsl:when test="comment/@type='text/html'">
						<xsl:for-each select="comment/*">
							<xsl:copy-of select="." />
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="comment"/>
					</xsl:otherwise>
				</xsl:choose>
		</div>

	
	</div>
	</xsl:if>
	</li>	
	</xsl:for-each>
</ol>
</xsl:for-each>

</div>

</body>
</html>
</xsl:template>


</xsl:stylesheet>
