<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/> 
<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>netView Demo</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>Displays Netviews as pseudo graphical networks</shortDescription>
<howTo>Click a network view and watch its nodes displayed on this web page with positions roughly resembling their original positions (no links are displayed). Move elements around as desired.</howTo> 
<!-- howTo: To be displayed in the generated web page instructing the user how to use the result-->
<comment>this stylesheet is only experimental in nature, but could eventually become the basis for a serious, complex represention of network views in HTML.
</comment>
<category>Viewer</category>
<complexity>simple</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-06-30</creationDate>
<modificationDate>2007-11-01</modificationDate>
<sourceType type="HU" version="5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">
<html>
<head>
	<xsl:call-template name="htmlhead"/>
	<xsl:call-template name="script_expandsection"/>
	<xsl:call-template name="script_drag"/>

<style type="text/css">
	.drag {position: relative; border: none cursor: move;}
	body {background-image: url('images/bgGrid.gif');  }
</style>

</head>
<body>

<xsl:call-template name="pagehead"/>

<h1 class="title">netView Demo</h1>

<div id="containerNetw">


<xsl:call-template name="menu"/>

<ul>
<xsl:for-each select="//netView">
<xsl:variable name="docid"><xsl:value-of select="generate-id()"/></xsl:variable>

<li>
<img src="images/mark.gif" alt="{@name}"/>
<a href="#" onClick="doSection({$docid})"><xsl:text> </xsl:text> <xsl:value-of select="@name"/>
</a>
</li>


<div id="{$docid}" class="drag" style="display:none;">
	<xsl:call-template name="doStuff"/>
</div>

</xsl:for-each>
</ul>

</div>

</body>
</html>
</xsl:template>

<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! -->

<xsl:template name="doStuff">
<xsl:for-each select="node">

<xsl:variable name="id">
	<xsl:value-of select="generate-id()"/>
</xsl:variable>

<xsl:variable name="top">
	<xsl:value-of select="@y"/>
</xsl:variable>

<xsl:variable name="left">
	<xsl:value-of select="@x"/>
</xsl:variable>

<xsl:variable name="obj">
	<xsl:value-of select="@obj"/>
</xsl:variable>

<xsl:variable name="zindex">
	<xsl:number level="any" />
</xsl:variable>

<xsl:variable name="quote">
	<xsl:value-of select="
		//q[@id = $obj]/@name | 
		//code[@id = $obj]/@name | 
		//memo[@id = $obj]/@name
		"/>
</xsl:variable>

<xsl:variable name="icon">
<xsl:choose>
	<xsl:when test="//q[@id = $obj]">squareTeal.gif</xsl:when>
	<xsl:when test="//code[@id = $obj]">squareRed.gif</xsl:when>
	<xsl:when test="//memo[@id = $obj]">squareOrange.gif</xsl:when>
	<xsl:otherwise>squareBlack.gif</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<div id="{$id}" class="drag" 
	style="
	position: absolute; 
	margin-left: 200px; 
	top: {$top}; 
	left: {$left}; 
	height:10px; 
	z-index: {$zindex}; 
	padding: 5;
	cursor: move; 
	">

<img src="images/{$icon}" alt="{$quote}" width="12px" height="12px"/>
<xsl:value-of select="$quote"/>
<xsl:if test="@name and @name!=''">
<xsl:attribute name="onMouseover">doSection(comment<xsl:value-of select="$id"/>)</xsl:attribute>
<xsl:attribute name="onMouseout">noSection(comment<xsl:value-of select="$id"/>)</xsl:attribute>
</xsl:if>
</div>
<div id="{$id}" style="display:none; border:1px solid; position:absolute; background-color: lightyellow; padding:5px; " >
<xsl:value-of select="@name"/>
</div>
</xsl:for-each>
</xsl:template>


<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! -->

<xsl:template name="menu">

<div id="inlinemenu">

<ul>
	<li>
		<a class="normal"  href="#inlinemenu" onclick="noSection(legend)" target="_self">Hide</a>
		<xsl:text> / </xsl:text>
		<a class="normal"  href="#inlinemenu" onclick="doSection(legend)" target="_self">show</a>
		<xsl:text> this menu </xsl:text>
	</li>
	<li>
		<a class="normal"  href="javascript:location.reload()" target="_self">Clear page</a>
	</li>
</ul>

<div id="legend">
	<div class="small"><img src="images/squareTeal.gif" alt=""/> = Quotation</div>
	<div class="small"><img src="images/squareRed.gif" alt=""/> = Code</div>
	<div class="small"><img src="images/squareOrange.gif" alt=""/> = Memo</div>
<p>
Reduce/enlarge font size in browser to increase/decrease viewing area (e.g., menu option or CTRL+mouse wheel).
</p>
<p>
Drag individual elements anywhere on screen. 
</p>

</div>
</div>

</xsl:template>

<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! -->


</xsl:stylesheet>