<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/> 
<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>


<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>Sortable Table</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>Sortable and searchable results table</shortDescription>
<comment>Using a sizable dose of javascript, this stylesheet allows for the interactive sorting and searching of codes and some of their related information. 
</comment>
<category>Report</category>
<complexity>medium</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-06-30</creationDate>
<modificationDate>2007-11-01</modificationDate>
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">
<html>
<head>

<script language="JavaScript" src="scripts/sortable_table.js"></script>

<script language="JavaScript">
<xsl:comment>

// Table/Data colors
tableBgColor=    '#ccc'
headerTxtColor=  '#333'
headerBgColor=   '#ededed'
dataTxtColor=    '#000000'
dataBgColor=     '#cfcfcf'
hilightRowColor= '#d55d60'
hilightBgColor=  '#d55d60'
linkTxtColor=    '#0033FF'
linkHoverColor=  '#FF6633'

// table width
tableWidth='80%'

// show row numbers
rowNumbersEnabled=true

// Table Heading (and any extra data)
tableTitle='Sortable/Searchable Table Example'
extraTableData="Instructions: Highlight rows by clicking them. Sort columns by clicking the ARROW in the header. Find data anywhere in the table by using the search facility. (Note: Search is Case sensitive.)<br/>"

tableHeadings=new Array();tableHeadings[0]=""
// Column Headings
tableHeadings[1]="Code"
tableHeadings[2]="Author"
tableHeadings[3]="Date"
tableHeadings[4]="Code Family"
// add more column headings here ...

tableData=new Array();
// Table/Column data
<xsl:for-each select="//code">
<xsl:variable name="uID"><xsl:value-of select="generate-id()"/></xsl:variable>
<xsl:variable name="stripName">
	<xsl:value-of select="translate(@name, '[]&quot;', '')"/>
</xsl:variable>
<xsl:variable name="id"><xsl:value-of select="@id"/></xsl:variable>

tableData[<xsl:value-of select="position() - 1"/>]=new dataArray(
	'<xsl:value-of select="@name"/>',
	'<xsl:value-of select="@au"/>',
	'<xsl:call-template name="properCDate"/>', 
		'<xsl:for-each select="//item[@id = $id]"><xsl:value-of select="ancestor::codeFamily/@name"/><xsl:text> </xsl:text></xsl:for-each>'
	);
</xsl:for-each>
</xsl:comment>
</script>
<link rel="stylesheet" href="{$stylesdir}updated.css" type="text/css" /> 
</head>

<body>

<xsl:call-template name="pagehead"/>
<h1 class="title">Sortable and Searchable Results Table</h1>

	<!-- Table start -->
	<div id="tableHolder"><script>createTable('table_name','tableHolder')</script></div>
	<!-- Table end -->

</body>
</html>
</xsl:template>


<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->


<xsl:template name="escape-javascript">
  <xsl:param name="string" />
  <xsl:choose>
    <xsl:when test='contains($string, "&apos;")'>
      <xsl:call-template name="escape-javascript">
        <xsl:with-param name="string"
          select='substring-before($string, "&apos;")' />
      </xsl:call-template>
      <xsl:text>\'</xsl:text>
      <xsl:call-template name="escape-javascript">
        <xsl:with-param name="string"
          select='substring-after($string, "&apos;")' />
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="contains($string, '&#xA;')">
      <xsl:call-template name="escape-javascript">
        <xsl:with-param name="string"
          select="substring-before($string, '&#xA;')" />
      </xsl:call-template>
      <xsl:text>\n</xsl:text>
      <xsl:call-template name="escape-javascript">
        <xsl:with-param name="string"
          select="substring-after($string, '&#xA;')" />
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="contains($string, '\')">
      <xsl:value-of select="substring-before($string, '\')" />
      <xsl:text>\\</xsl:text>
      <xsl:call-template name="escape-javascript">
        <xsl:with-param name="string"
          select="substring-after($string, '\')" />
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise><xsl:value-of select="$string" /></xsl:otherwise>
  </xsl:choose>
</xsl:template>




<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
<!-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->


</xsl:stylesheet>

