<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/> 
<xsl:variable name= "description" select="document('')//atlasDescription" />
<xsl:include href="_shared.xsl.inc"/>

<atlas:data xmlns:atlas="urn:www.atlasti.com/xml/001">
<atlasDescription version = "1.0"> <!-- Version of this description syntax -->
<friendlyName>XML Codes for ATLAS.ti 4</friendlyName> <!-- To be displayed in ATLAS.ti -->
<shortDescription>Converts to ATLAS.ti 4.x XML code format</shortDescription>
<comment>Converts ATLAS.ti 5.x XML to ATLAS.ti 4.x XML format for rudimentary backward compatibility. 
Note: This conversion produces xml embedded in html; extract by cutting &amp; pasting) 
</comment>
<category>Converter</category>
<complexity>simple</complexity> <!-- Computational complexity -->
<iconPath></iconPath> <!-- To be displayed in ATLAS.ti -->
<author name="Thomas Ringmayr" email="xml@support.atlasti.com" url="www.atlasti.com/xml.html"/>
<creationDate>2003-06-30</creationDate>
<modificationDate>2007-11-01</modificationDate>
<sourceType type = "HU" version = "5.0"/> <!-- XML type acccepted as input -->
<targetDocType>HTML</targetDocType> 
</atlasDescription>
</atlas:data>


<xsl:template match="/">
<html>

<head>
	<xsl:call-template name="htmlhead"/>
</head>

<body>

<xsl:call-template name="pagehead"/>

<h1 class="title">Version 4 XML</h1>

<p class="instruction">Copy/paste everything below to a a text editor and save with an ".xml" extension. Voila, instant ATLAS.ti 4 XML!</p>

<hr/>
<p/>
<span style="color:green">&lt;?xml version="1.0"?></span>
<p/>
&lt;<span class="element">CODEBASE</span><br/>
<xsl:text> </xsl:text><span class="attribute">HU</span>="<xsl:value-of select="//hermUnit/@name"/>"<br/>
<xsl:text> </xsl:text><span class="attribute">AUTHOR</span>="<xsl:value-of select="//hermUnit/@au"/>"<br/>
<xsl:text> </xsl:text><span class="attribute">TQCOUNT</span>="<xsl:value-of select="sum(//codes/code/@qCount)"/>"<br/>
<xsl:text> </xsl:text><span class="attribute">TCCOUNT</span>="<xsl:value-of select="sum(//codes/code/@cCount)"/>"<br/>
<xsl:text> </xsl:text><span class="attribute">CODINGS</span>="<xsl:value-of select="sum(//codes/code/@qCount) + sum(//codes/code/@cCount)"/>"
&gt;
<p/>

<xsl:for-each select="//codes/code">

&lt;<span class="element">CODE</span>
<xsl:text> </xsl:text><span class="attribute">QCOUNT</span>="<xsl:value-of select="@qCount"/>"
<xsl:text> </xsl:text><span class="attribute">CCOUNT</span>="<xsl:value-of select="@cCount"/>"&gt;

<br/>
&lt;<span class="element">TITLE</span>&gt;<xsl:value-of select="@name"/>&lt;/<span class="element">TITLE</span>&gt;<br/>
&lt;<span class="element">DATE</span>&gt;<xsl:call-template name="reformatDate"/>&lt;/<span class="element">DATE</span>&gt;<br/>
&lt;<span class="element">AUTHOR</span>&gt;<xsl:value-of select="@au"/>&lt;/<span class="element">AUTHOR</span>&gt;<br/>
&lt;<span class="element">COMMENT</span>&gt;<xsl:if test="comment and comment!=''"></xsl:if>
<xsl:if test="comment and comment!=''">
	<!--<pre class="content"><xsl:value-of select="comment"/></pre>-->
					<xsl:choose>
					<xsl:when test="comment/@type='text/html'">
						<xsl:for-each select="comment/*">
							<xsl:copy-of select="." />
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="comment"/>
					</xsl:otherwise>
				</xsl:choose>
</xsl:if>&lt;/<span class="element">COMMENT</span>&gt;

<br/>&lt;/<span class="element">CODE</span>&gt;
<p/>

</xsl:for-each>
&lt;/<span class="element">CODEBASE</span>&gt;

</body>
</html>
</xsl:template>

<xsl:template name="reformatDate"><xsl:value-of select="@cDate"/></xsl:template>

</xsl:stylesheet>
